Learn R Programming

fitPS (version 1.0.1)

confint.psFit: S3 confint method for objects of class psFit

Description

S3 confint method for objects of class psFit

Usage

# S3 method for psFit
confint(object, parm, level = 0.95, ...)

Value

if the zeta model is used (i.e object comes from a call to

fitDist),then a list with two items: wald and

prof containing the Wald and profile likelihood confidence intervals respectively for the shape parameter of the fitted zeta distribution is returned. In general these should be relatively close to each other. **NOTE** These values are for the VGAM parameterisation of the Zeta distribution which uses \(s^\prime = s - 1\). This means they can be used without alteration in dzeta. If a zero-inflated zeta model is used (i.e. object comes from a call to

fitZIDist) then list of a confidence regions is returned with and element for each value of level. The confidence regions are

data.frames with variables pi and shape which can be used with lines or polygon

to draw a the confidence region.

Arguments

object

an object of class psFit---see fitDist for more details

parm

added for compatibility. Should be left empty as it is ignored.

level

the confidence level required---restricted to [0.75, 1)

...

in theory other parameters to be passed to confint, but in reality passed as extra parameters to the internal function plZIZ.

Details

NOTE: the method for ZIZ model is a little computationally intensive and possibly (almost certainly) unstable.

Examples

Run this code
data(Psurveys)
roux = Psurveys$roux
fit = fitDist(roux)
confint(fit)

if (FALSE) {
fit.zi = fitZIDist(roux)
cr = confint(fit.zi, level = c(0.80, 0.95))
plot(cr[["0.95"]], type = "l")
polygon(cr[["0.8"]])
}

Run the code above in your browser using DataLab