Learn R Programming

fitPS (version 1.0.1)

fitted.psFit: S3 fitted method for an object of class psFit

Description

S3 fitted method for an object of class psFit

Usage

# S3 method for psFit
fitted(object, n = NULL, ...)

Value

a named vector of fitted probabilities

Arguments

object

an object of class psFit, usually from fitDist or fitZIDist.

n

This parameter is NULL by default. If it is not NULL then it must be either the number of fitted terms to be return, or, a vector containing the desired fitted values.

...

other arguments passed to fitted---not used.