if the zeta model is used (i.e object comes from a call to
fitDist),then a list with two items: wald and
prof containing the Wald and profile likelihood confidence intervals
respectively for the shape parameter of the fitted zeta distribution is
returned. In general these should be relatively close to each other.
**NOTE** These values are for the VGAM parameterisation of the Zeta
distribution which uses \(s^\prime = s - 1\). This means they
can be used without alteration in dzeta. If a
zero-inflated zeta model is used (i.e. object comes from a call to
fitZIDist) then list of a confidence regions is returned with
and element for each value of level. The confidence regions are
data.frames with variables pi and shape which can be
used with lines or polygon
to draw a the confidence region.